@@ -1,15 +1,23 @@
-is_multiadm = function(x){
+is_multiadm = function(x, quietly = TRUE){
   
   #'
   #' @title is valid multiadm object?
   #' 
   #' @param x object to be tested
+  #' @param quietly logical, should a descriptive warning be returned?
   #' 
-  #' @returns Boolean. Is the object a valid multiadm object?
+  #' @returns Logical. Is the object a valid multiadm object?
   #' 
   
+  
+  warning_status = getOption("warn")
+  if (quietly){
+    options("warn" = -1)
+  }
+  
   if ( ! inherits(x, "multiadm") ){
     warning("Expected multiadm class")
+    options("warn" = warning_status)
     return(FALSE)
   }
   
@@ -17,14 +25,17 @@ is_multiadm = function(x){
   has_valid_names = all( names(x) %in% c("t","h","destr","no_of_entries", "T_unit", "L_unit"))
   if (! has_valid_names){
     warning("Invalid names")
+    options("warn" = warning_status)
     return(FALSE)
   }
   
   if (length(names(x)) != 6){
     warning("Missing name fields")
+    options("warn" = warning_status)
     return(FALSE)
   }
   
+  options("warn" = warning_status)
   return(TRUE)
   
 }
\ No newline at end of file
