@@ -14,6 +14,14 @@ test_that("Completeness of 0.5 for accumulation half of time", {
   expect_equal( get_incompleteness( adm), 0.5)
 })
 
+test_that("Completeness of 1?3 for accumulation half of time", {
+  t = 1:4
+  h = c(2,2,3,4)
+  adm = tp_to_adm(t = t, h = h)
+  expect_equal( get_completeness( adm), 2/3)
+  expect_equal( get_incompleteness( adm), 1/3)
+})
+
 test_that("Completeness of 0 for non-accumulation", {
   t = 1:3
   h = c(2,2,2)
